v26.1.1, Jan. 2026 -- Code cleanup, minor bug fixes and improvements, add dispersion picking feature

v25.12.4, Dec. 2025 -- Minor dependency fix

v25.12.3, Dec. 2025 -- Add shot stacking, improved packaging, file handling, batch editing, minor display fixes

v25.12.2, Dec. 2025 -- Minor fixes, code cleanup

v25.12.1, Dec. 2025 -- Major UI modification, improve loading picks logic, debug ipython consol, fix trace editing

v25.11.1, Nov. 2025 -- Add autopicking, add spectro and dispersion views, minor fixes and improvements

v25.10.1, Oct. 2025 -- Add bottom menu and coord display, fix picks loading (partly - still behaves weirdly with roll alongs), other small fixes

v25.9.4, Sep. 2025 -- Fix batch import and edit, fix view, add help, try icons

v25.9.3, Sep. 2025 -- Mouse and display controls improvements

v25.9.2, Sep. 2025 -- Handle SEG2 correctly

v25.9.1, Sep. 2025 -- Surface-wave analysis module (beta)

v25.6.5, Jun. 2025 -- Minor fixes, run inversion module from terminal

v25.6.4, Jun. 2025 -- Improved inversion module

v25.6.3, Jun. 2025 -- Code structure improvements, prints/message/loading box, add move trace option

v25.6.2, Jun. 2025 -- Improved inversion module

v25.6.1, Jun. 2025 -- Add seismogram image display, improved mouse controls

v25.4.3, Apr. 2025 -- Minor fixes, remove and mute traces

v25.4.2, Apr. 2025 -- New saving and nav options, inversion with pygmli, better packaging

v25.4.1, Apr. 2025 -- Save all shots in single SEGY or SU file, navigate to shots from bottom plot, inversion with pyGIMLi

v25.3.2, Mar. 2025 -- Fix rounding errors, better figure export, fix segy/su export

v25.3.1, Mar. 2025 -- Minor fixes, export figures, pick colormap, import specific columns in topo file, dark mode, save picks in previous file, warning at clearance

v25.2.2, Feb. 2025 -- Minor fixes, improved handling of redundant FFID

v25.2.1, Feb. 2025 -- Minor fixes, improved header dialog, menu re-organization, edit FFID

v25.1.9, Jan. 2025 -- Minor fixes, save segy and su files with modified headers

v25.1.8, Jan. 2025 -- Minor fixes, monkey patch for _getFillPath in pyqtgraph, add colorbar

v25.1.7, Jan. 2025 -- Minor fixes, edit headers, remove shots

v25.1.6, Jan. 2025 -- Minor fixes, set delay header

v25.1.5, Jan. 2025 -- Minor fixes, import and show topography

v25.1.4, Jan. 2025 -- Minor fixes, add air wave, show headers

v25.1.3, Jan. 2025 -- Supports automatic packaging and release on PyPi, and running with 'pyckster' command in the terminal

v25.1.0, Jan. 2025 -- Initial release.